@@ -201,7 +201,7 @@ static int kldap_sasl_interact( sasl_interact_t *interact, LdapOperation::SASL_D
   QString value;
 
   while ( interact->id != SASL_CB_LIST_END ) {
-    value = QString();
+    value.clear();
     switch( interact->id ) {
     case SASL_CB_GETREALM:
       value = data->creds.realm;
@@ -409,6 +409,10 @@ int LdapOperation::LdapOperationPrivate::processResult( int rescode, LDAPMessage
     mObject.setAttributes( attrs );
     break;
   }
+  case RES_SEARCH_REFERENCE:
+    // Will only get this if following references is disabled. ignore it
+    rescode = 0;
+    break;
   case RES_EXTENDED:
   {
     char *retoid;
@@ -469,7 +473,7 @@ int LdapOperation::LdapOperationPrivate::processResult( int rescode, LDAPMessage
       }
       ldap_memfree( (char *) referralsp );
     }
-    mMatchedDn = QString();
+    mMatchedDn.clear();
     if ( matcheddn ) {
       mMatchedDn = QString::fromUtf8( matcheddn );
       ldap_memfree( matcheddn );
@@ -674,7 +678,7 @@ int LdapOperation::search( const LdapDN &base, LdapUrl::Scope scope,
   }
 
   kDebug() << "asyncSearch() base=\"" << base.toString()
-           << "\" scope=" << scope
+           << "\" scope=" << (int)scope
            << "filter=\"" << filter
            << "\" attrs=" << attributes;
   int retval =
