@@ -20,27 +20,37 @@
 #ifndef MAILTRANSPORT_TRANSPORT_H
 #define MAILTRANSPORT_TRANSPORT_H
 
-#include <mailtransport/transportbase.h>
 #include <mailtransport/mailtransport_export.h>
+#include <mailtransport/transportbase.h>
+#include <mailtransport/transporttype.h>
 
 class TransportPrivate;
 
 namespace MailTransport {
 
+class TransportType;
+
 /**
   Represents the settings of a specific mail transport.
 
   To create a new empty Transport object, use TransportManager::createTransport().
 */
+// TODO KDE5: Do something about the kcfg-generated TransportBase.
+// Currently it has the config stuff as private members, which means it is
+// utterly inextensible.  Also the sendmail and akonadi-type transports use
+// the "host" setting for keeping the location of the sendmail executable and
+// the resource id, respectively.  This is a hack; they should have separate
+// config options... (cberzan)
 class MAILTRANSPORT_EXPORT Transport : public TransportBase
 {
   Q_OBJECT
   friend class TransportManager;
+  friend class TransportManagerPrivate;
 
   public:
-      /**
-        Destructor
-       */
+    /**
+      Destructor
+    */
     virtual ~Transport();
 
     typedef QList<Transport*> List;
@@ -61,6 +71,13 @@ class MAILTRANSPORT_EXPORT Transport : public TransportBase
     */
     void setPassword( const QString &passwd );
 
+    /**
+      Makes sure the transport has a unique name.  Adds #1, #2, #3 etc. if
+      necessary.
+      @since 4.4
+    */
+    void forceUniqueName();
+
     /**
       This function synchronizes the password of this transport with the
       password of the transport with the same ID that is managed by the
@@ -95,6 +112,20 @@ class MAILTRANSPORT_EXPORT Transport : public TransportBase
     */
     Transport *clone() const;
 
+    /**
+      Returns the type of this transport.
+      @see TransportType.
+      @since 4.4
+    */
+    TransportType transportType() const;
+
+    /**
+      Sets the type of this transport.
+      @see TransportType.
+      @since 4.4
+    */
+    void setTransportType( const TransportType &type );
+
   protected:
     /**
       Creates a Transport object. Should only be used by TransportManager.
@@ -116,12 +147,14 @@ class MAILTRANSPORT_EXPORT Transport : public TransportBase
     void migrateToWallet();
 
   private Q_SLOTS:
+
+    // Used by our friend, TransportManager
     void readPassword();
 
   private:
     TransportPrivate *const d;
 };
 
-}
+} // namespace MailTransport
 
-#endif
+#endif // MAILTRANSPORT_TRANSPORT_H
